@@ -17,7 +17,7 @@ use namespace::autoclean;
 extends 'App::Sqitch::Command';
 with 'App::Sqitch::Role::ContextCommand';
 
-our $VERSION = 'v1.4.0'; # VERSION
+our $VERSION = 'v1.4.1'; # VERSION
 
 has change_name => (
     is  => 'ro',
@@ -121,7 +121,7 @@ sub _config_templates {
 sub all_templates {
     my ($self, $name) = @_;
     my $config = $self->sqitch->config;
-    my $tmpl   = $self->templates;
+    my $tmpl   = { %{ $self->templates } };
 
     # Read all the template directories.
     for my $dir (
@@ -543,7 +543,7 @@ David E. Wheeler <david@justatheory.com>
 
 =head1 License
 
-Copyright (c) 2012-2023 iovation Inc., David E. Wheeler
+Copyright (c) 2012-2024 iovation Inc., David E. Wheeler
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
